==> rca-precursor-0.1.20.tgz: package/src/webpack/webpack.config.js <==
//  @flow
import path from 'path';
import reduce from 'lodash/reduce';

import { getBundleEntriesFromRoutes } from './../utils/bundling';
import getLoaders from './loaders.config';
import getPlugins from './plugins.config';
import defaultConfig from './defaultConfig';

import type { IConfig } from '../../flow/IConfig';

export default (config: IConfig) => {
  const {
    context = path.resolve(process.cwd(), './src'),
    entry,
    distOutput = defaultConfig.distOutput,
    publicPath = defaultConfig.publicPath,
    jsPath = defaultConfig.jsPath,
    isDevEnvironment,
    routes,
  } = config;

  if (!entry) {
    throw new Error('No entry files are specified');
  }

  //  Extract bundles from routes
  const bundles = getBundleEntriesFromRoutes(routes);

  return {
    context,

    entry: {
      ...entry,
      ...bundles,
      ...(isDevEnvironment) && {
        hotReload: 'webpack-hot-middleware/client?reload=true',
      },
    },

    output: {
      filename: (!isDevEnvironment)
        ? `${jsPath}/[name].[chunkhash].bundle.js`
        : `${jsPath}/[name].bundle.js`,
      path: path.join(process.cwd(), distOutput, publicPath),
      publicPath,
      chunkFilename: `${jsPath}/[name].[chunkhash].js`,
    },

    resolve: {
      alias: reduce(bundles, (acc, location, chunkName) => {
        acc[chunkName] = path.join(context, location);
        return acc;
      }, {}),
      modules: [
        context,
        path.join(process.cwd(), 'node_modules'),
      ],
    },

    //  Add devServer and source maps
    //  when running in development
    ...(isDevEnvironment) && {
      devServer: {
        contentBase: publicPath,
        hot: true,
        inline: true,
        historyApiFallback: true,
      } && {
        devtool: 'cheap-module-source-map',
      },
    },

    module: {
      rules: getLoaders(config),
    },
    plugins: getPlugins(config),
  };
};

==> rca-precursor-0.1.21.tgz: package/src/webpack/webpack.config.js <==
//  @flow
import path from 'path';

import { getBundleEntriesFromRoutes } from './../utils/bundling';
import getLoaders from './loaders.config';
import getPlugins from './plugins.config';
import defaultConfig from './defaultConfig';

import type { IConfig } from '../../flow/IConfig';

export default (config: IConfig) => {
  const {
    context = path.resolve(process.cwd(), './src'),
    entry,
    distOutput = defaultConfig.distOutput,
    publicPath = defaultConfig.publicPath,
    jsPath = defaultConfig.jsPath,
    isDevEnvironment,
    routes,
  } = config;

  if (!entry) {
    throw new Error('No entry files are specified');
  }

  //  Extract bundles from routes
  const bundles = getBundleEntriesFromRoutes(routes);

  return {
    context,

    entry: {
      ...entry,
      ...bundles,
      ...(isDevEnvironment) && {
        hotReload: 'webpack-hot-middleware/client?reload=true',
      },
    },

    output: {
      filename: (isDevEnvironment)
        ? `${jsPath}/[name].bundle.js`
        : `${jsPath}/[name].[chunkhash:8].bundle.js`,
      chunkFilename: (isDevEnvironment)
        ? `${jsPath}/[name].chunk.js`
        : `${jsPath}/[name].[chunkhash:8].chunk.js`,
      path: path.join(process.cwd(), distOutput, publicPath),
      publicPath,
    },

    //  Add devServer and source maps
    //  when running in development
    ...(isDevEnvironment) && {
      devServer: {
        contentBase: publicPath,
        hot: true,
        inline: true,
        historyApiFallback: true,
      } && {
        devtool: 'cheap-module-source-map',
      },
    },

    module: {
      rules: getLoaders(config),
    },
    plugins: getPlugins(config),
  };
};
